# -*- coding: utf-8 -*-

from matplotlib.figure import Figure
from matplotlib.backends.backend_qtagg import FigureCanvas
from PyQt6.QtWidgets import (QApplication, QWidget, QLabel, QLineEdit, QHBoxLayout,
                             QPushButton, QMessageBox, QFileDialog, QVBoxLayout,
                             QFormLayout, QInputDialog, QMainWindow)
from PyQt6.QtCore import Qt
import numpy as np
from relative_dose_1d.tools import identify_format, get_data, gamma_1D, build_from_array_and_step
import sys
import os
import copy

class GUI(QWidget):

    def __init__(self, D_ref = None, D_eval = None):
        """Constructor for a graphical user interface (GUI). Data has to be in 2 columns, 
        corresponding to positions and dose values, respectively.

        Parameters
        ----------

        D_ref : ndarray,
            Reference dose profile represented by a (M, 2) numpy array.  

        D_eva : ndarray,
            Dose profile to be evaluated, represented by a (N, 2) numpy array.

        Returns
        -------

        A PyQt widget to showing dose profiles, gamma analysis and dose difference.

        """
        super().__init__()

        self.D_ref = D_ref
        self.D_eval = D_eval

        self.initializeUI()

    def initializeUI(self):
        """Set up the apllication"""
        "x, y, width, height"
        self.setGeometry(200,100,1000,400)
        self.setWindowTitle("Relative dose 1D")

        self.set_up_window()
        self.set_up_data()
        self.show()

    def set_up_window(self):

        "Layouts definition"
        self.main_box_layout = QHBoxLayout()
   
        self.v_box_layout = QVBoxLayout()
        self.settings_layout_v = QVBoxLayout()
        
        self.Q_grafica = Q_Base_Figure() 

        self.main_box_layout.addLayout(self.settings_layout_v)
        self.main_box_layout.addLayout(self.v_box_layout)

        self.setLayout(self.main_box_layout)

        self.open_file_button = QPushButton("Load a text file", self)
        self.open_file_button.clicked.connect(self.open_file_button_clicked)

        self.clear_button = QPushButton("Clear", self)
        self.clear_button.clicked.connect(self.clear_data_and_plots)
        
        self.button_factor = QPushButton("Scale factor", self)
        self.button_factor.clicked.connect(self.factor_button_clicked)
        self.button_factor.setFixedSize(80, 40)
        self.button_factor.setEnabled(False)

        self.button_origin = QPushButton("Move origin", self)
        self.button_origin.clicked.connect(self.move_button_clicked)
        self.button_origin.setFixedSize(80, 40)
        self.button_origin.setEnabled(False)

        axis_label = QLabel("Axis position")
        #axis_label.setFont(QFont(Arial, 15))
        self.settings_layout_v.addWidget(axis_label, alignment = Qt.AlignmentFlag.AlignHCenter)
        self.settings_layout_v.addWidget(self.button_factor)
        self.settings_layout_v.addWidget(self.button_origin)
        self.settings_layout_v.addWidget(QLabel("Gamma", alignment = Qt.AlignmentFlag.AlignHCenter))

        gammaLayout = QFormLayout()
        self.dose_t_QLine = QLineEdit()
        self.dose_t_QLine.setFixedWidth(40)
        self.dose_t_QLine.setText("3.0")
        self.DTA_t_QLine = QLineEdit()
        self.DTA_t_QLine.setFixedWidth(40)
        self.DTA_t_QLine.setText("2.0")
        self.thres_QLine = QLineEdit()
        self.thres_QLine.setFixedWidth(40)
        self.thres_QLine.setText("0.0")
        self.interp_QLine = QLineEdit()
        self.interp_QLine.setFixedWidth(40)
        self.interp_QLine.setText("1")
        gammaLayout.addRow("Dose [%]:", self.dose_t_QLine)
        gammaLayout.addRow("DTA [mm]:", self.DTA_t_QLine)
        gammaLayout.addRow("Threshold [%]:", self.thres_QLine)
        gammaLayout.addRow("Interp.:", self.interp_QLine)

        self.gamma_button = QPushButton("Apply")
        self.gamma_button.clicked.connect(self.calc_difference_and_gamma)
        self.gamma_button.setFixedSize(120, 40)
        #self.button_origin.setEnabled(False)

        results_label = QLabel("Results", alignment = Qt.AlignmentFlag.AlignHCenter)
        self.gamma_rate_label = QLabel("Pass rate: ")
        self.total_points_label = QLabel("Total points: ")
        self.evaluated_points_label = QLabel("Evaluated ponits: ")

        self.settings_layout_v.addLayout(gammaLayout)
        self.settings_layout_v.addWidget(self.gamma_button)
        self.settings_layout_v.addWidget(results_label)
        self.settings_layout_v.addWidget(self.gamma_rate_label)
        self.settings_layout_v.addWidget(self.total_points_label)
        self.settings_layout_v.addWidget(self.evaluated_points_label)

        self.settings_layout_v.addStretch()
         
        self.v_box_layout.addWidget(self.open_file_button)
        self.v_box_layout.addWidget(self.clear_button)
        self.v_box_layout.addWidget(self.Q_grafica.Qt_fig)
        
    def set_up_data(self):
        if self.D_ref is None:
            self.loaded_data = []
        else:          
            self.loaded_data = [self.D_ref, self.D_eval]
            self.Q_grafica.plot_data(self.D_ref)
            self.Q_grafica.plot_data(self.D_eval)
            self.calc_difference_and_gamma()

    # Button's functions

    def open_file_button_clicked(self):
        self.last_file_name, _ = QFileDialog.getOpenFileName()
        _ , extension = os.path.splitext(self.last_file_name)

        if self.last_file_name:
            with open(self.last_file_name, encoding='UTF-8', mode = 'r') as file:
                all_list = [line.strip() for line in file]

            format = identify_format(all_list)

            if format == 'text_file':
                self.show_new_window()  #New window for input user parameters.

            else:
                data = get_data(self.last_file_name)
                self.load_data(data)

    def clear_data_and_plots(self):
        self.Q_grafica.ax_perfil.clear()
        self.Q_grafica.ax_perfil_resta.clear()
        self.Q_grafica.ax_gamma.clear()
        self.Q_grafica.fig.canvas.draw()
        self.open_file_button.setEnabled(True)
        self.loaded_data = []

    def clear_gamma(self):
        self.Q_grafica.ax_perfil_resta.clear()
        self.Q_grafica.ax_gamma.clear()

    def factor_button_clicked(self):
        scale_factor, ok = QInputDialog.getText(self, 'Scale factor', 'Scale factor:')
        try:
            scale_factor = float(scale_factor)
            if ok:
                self.loaded_data[-1][:,0] = self.loaded_data[-1][:,0] * scale_factor
                cache_data = copy.deepcopy(self.loaded_data)
                self.clear_data_and_plots()

                for data in cache_data:
                    self.load_data(data)

        except ValueError:
            QMessageBox().critical(self, "Error", "Enter a number.")
            print('Error, give a number.')

    def move_button_clicked(self):
        delta, ok = QInputDialog.getText(self, 'Scale factor', 'Origin displacement:')
        try:
            delta = float(delta)
            if ok:
                self.loaded_data[-1][:,0] = self.loaded_data[-1][:,0] + delta
                cache_data = copy.deepcopy(self.loaded_data)
                self.clear_data_and_plots()

                for data in cache_data:
                    self.load_data(data)

        except ValueError:
            QMessageBox().critical(self, "Error", "Enter a number.")
            print('Error, give a number.')        

    def show_new_window(self):
        start_word, ok = QInputDialog.getText(self, 'Text Input Dialog', 'Start word:')
        if ok:
            data = get_data(self.last_file_name, start_word)
        else:
            data = get_data(self.last_file_name)
                
        self.load_data(data)
    
    #   Additional functions

    def load_data(self, data):
        
        self.loaded_data.append(data)       
        self.Q_grafica.plot_data(data)
        self.button_factor.setEnabled(True)
        self.button_origin.setEnabled(True)
        if len(self.loaded_data) == 2:
            self.calc_difference_and_gamma()

    def calc_difference_and_gamma(self):

        data_A = self.loaded_data[0]
        data_B = self.loaded_data[1]

        # Using interpolation, new values ​​of B are computed at positions given by A.
        data_B_from_A_positions = np.interp(data_A[:,0], data_B[:,0], data_B[:,1], left = np.nan)
    
        difference = data_A[:,1] - data_B_from_A_positions

        added_positions = np.array((data_A[:,0], difference))
        values = np.transpose(added_positions)
       
        g, g_percent, evaluated_points = gamma_1D(
            data_A, 
            data_B,
            dose_t = float(self.dose_t_QLine.text()),
            dist_t = float(self.DTA_t_QLine.text()),
            dose_threshold = float(self.thres_QLine.text()),
            interpol = int(self.interp_QLine.text()),
            )

        self.Q_grafica.plot_resta(values)
        self.Q_grafica.ax_gamma.clear()
        #self.Q_grafica.ax_gamma = self.Q_grafica.ax_perfil_resta.twinx()
        self.Q_grafica.plot_gamma(g)
        #self.Q_grafica.ax_gamma.set_ylabel('gamma')
        self.gamma_rate_label.setText(f"Pass rate: {g_percent:0.1f}%")
        self.total_points_label.setText(f"Total points: {data_A.shape[0]:0.1f}")
        self.evaluated_points_label.setText(f"Evaluated ponits: {evaluated_points:0.1f}")

class Q_Base_Figure:
        
    def __init__(self):
        self.fig = Figure(figsize=(40,4), tight_layout = True, facecolor = 'whitesmoke')
        self.Qt_fig = FigureCanvas(self.fig)

        #   Axes para la imagen
        self.ax_perfil = self.fig.add_subplot(1, 2, 1)
        self.ax_perfil.set_ylabel('Percentage [%]')
        self.ax_perfil.set_xlabel('Distance [mm]')
        self.ax_perfil.grid(alpha = 0.3)

        self.ax_perfil_resta =  self.fig.add_subplot(1, 2, 2)
        self.ax_perfil_resta.set_ylabel('Percentage [%]')
        self.ax_perfil_resta.set_xlabel('Distance [mm]')
        self.ax_perfil_resta.grid(alpha = 0.3)

        self.ax_gamma = self.ax_perfil_resta.twinx()
        self.ax_gamma.set_ylabel('gamma')
        #self.ax_gamma.set_ylim((0, 2))
        
    def plot_data(self, data):
        x = data[:,0]
        y = data[:,1]
        self.ax_perfil.plot(x, y)
        self.ax_perfil.set_ylabel('Percentage [%]')
        self.ax_perfil.set_xlabel('Distance [mm]')
        self.ax_perfil.grid(alpha = 0.3)
        #self.ax_perfil.legend()
        self.fig.canvas.draw()
        
    def plot_resta(self, data):
        x = data[:,0]
        y = data[:,1]
        self.ax_perfil_resta.plot(x, y, color='r', label = 'Difference', alpha = 0.7)
        self.ax_perfil_resta.set_ylabel('Difference')
        self.ax_perfil_resta.set_xlabel('Distance [mm]')
        self.ax_perfil_resta.grid(alpha = 0.4)
        self.ax_perfil_resta.legend(loc = 'upper left')

        self.fig.canvas.draw()

    def plot_gamma(self, data):
        x = data[:,0]
        y = data[:,1]

        self.ax_gamma.plot(x, y, color='g', label = 'gamma', marker = '.')
        self.ax_gamma.plot(x, np.ones(x.shape[0]), 'g--', alpha = 0.5, linewidth=2)
        self.ax_gamma.set_ylabel('gamma')
        self.ax_gamma.yaxis.set_label_position("right")
        self.ax_gamma.legend(loc = 'upper right')

        self.fig.canvas.draw()

def plot(D_ref, D_eval):
    """
    A function to show a graphical user interface (GUI) to showing 1D dose profiles, 
    gamma analysis and dose difference. Data has to be in 2 columns, 
    corresponding to positions and dose values, respectively.

    Parameters
    ----------

    D_ref : ndarray,
        Reference dose profile represented by a (M, 2) numpy array.  

    D_eva : ndarray,
        Dose profile to be evaluated, represented by a (N, 2) numpy array.

    Returns
    -------

    A GUI showing dose profiles, gamma analysis and dose difference.

    Examples
    --------

    >>> import relative_dose_1d.GUI_tool as rd

    >>> a = np.array([0,1,2,3,4,5,6,7,8,9,10])
    >>> b = a + np.random.random_sample((11,))

    >>> A = build_from_array_and_step(a, 1)
    >>> B = build_from_array_and_step(b, 1)
    
    >>> rd.plot(A,B)

    """

    app = QApplication(sys.argv)    
    window = GUI(D_ref, D_eval)
    sys.exit(app.exec())

def run_demo():

    a = np.array([0,1,2,3,4,5,6,7,8,9,10])
    b = a + np.random.random_sample((11,))

    A = build_from_array_and_step(a, 1)
    B = build_from_array_and_step(b, 1)
    
    plot(A,B)

if __name__ == '__main__':
    
    a = np.array([0,1,2,3,4,5,6,7,8,9,10])
    b = a + np.random.random_sample((11,))
    A = build_from_array_and_step(a, 1)
    B = build_from_array_and_step(b, 1)
    
    app = QApplication(sys.argv)
    window = GUI(A, B)
    sys.exit(app.exec())


# -*- coding: utf-8 -*-
"""
Created on Mon Apr 24 2023

@author: Luis Alfonso Olivares Jimenez

Tools to read 1-dimensional dose profiles and perform gamma index comparison.

The data should be in M ​​rows by 2 columns, corresponding to positions and
dose values, respectively.

The script has been tested with the following examples:

    * File in w2CAD format (format used by the TPS Eclipse 16.1, from the Varian(R) company).
      In the algorithm, the start of the data is identified by the words: '$STOM' or '$STOD'
      Physical unit assumed to be in mm.

    * File in mcc format (format used by Verisoft 7.1.0.199 software, from PTW(R) company).
      In the algorithm, the beginning of the data is identified by the word: 'BEGIN_DATA'
      Physical unit assumed to be in mm.

    * File in text format
      The data must be distributed in M ​​rows by 2 columns and separated
      for a blank space.
      The script ask for a word to identify the beginning of the data in the text file, 
      a number to add to the positions, and a factor for distance dimension conversion.

"""

import numpy as np

def text_to_list(file_name):
    """
    Convert a text file to a python list. Each element of the list 
    represents a line from the text file.

    Parameters
    ----------

    file_name : string
        Text file name
    
    Returns
    -------

    list
        Loaded data as a list.
    
    """
    with open(file_name, encoding='UTF-8', mode = 'r') as file:
        data_list = [line.strip() for line in file]    
    return data_list


def identify_format(data_list):
    """
    Identify text format.

    Parameters
    ----------

    data_list : list
        Each element of the list represents a line from the text file.

    Returns
    -------

    string
        'varian' for w2CAD format, identified by the '$' character at the beginning of the file.

        'ptw' for mcc fromat, identified by the word 'BEGIN_SCAN_DATA'.

        'just_numbers' for data without headers.
        
        'text_file' for other formats. 

    """

    if data_list[0][0] == '$':
        return 'varian'

    elif data_list[0] == 'BEGIN_SCAN_DATA':
        return 'ptw'
    
    else: 
        is_a_number = data_list[0].split()[0]
        try:
            float(is_a_number)
            return 'just_numbers'
        
        except ValueError:
            return 'text_file'


def get_data(file_name, 
             start_word = None, 
             end_word = None,
             delta = None):
    
    """
    Get and normalize data from a text-file (file that is structured as a sequence of lines).
    Since w2CAD and mcc formats are automatically detected, it is not necessary 
    to specify start/end words in such cases.
    
    Parameters
    ----------

    file_name : string
        Name of the file

    start_word : string 
        Word to identify the beginning of the data

    end_word : string 
        Word to identify the end of the data

    delta : float 
        Displacement in mm to define the started point
    
        
    Returns
    -------

    ndarray
        Data as a Numpy object
    
    """

    all_list = text_to_list(file_name)
    file_format = identify_format(all_list)
    

    #   w2CAD format (Varian)
    
    if file_format == 'varian':
        if '$STOM' in all_list:
            start_index = all_list.index('$STOM') + 1
            end_index = all_list.index('$ENOM')         #Find the beginning and end of the data
            
        elif '$STOD' in all_list:
            start_index = all_list.index('$STOD') + 1
            end_index = all_list.index('$ENOD')
            
        data_list = all_list[start_index: end_index]
        # Extraer datos de las lineas que comienzan con el caracter '<'
        data_list = [idx[1:-1].split() for idx in data_list if idx[0] == "<"]
        data_array = np.array(data_list).astype(float)
        data_array[:,1] = 100*data_array[:,1]/np.amax(data_array[:,1])
        

    #   mcc format (PTW)     

    elif file_format == 'ptw':

        start_index = all_list.index('BEGIN_DATA') + 1  
        end_index = all_list.index('END_DATA')          #Find the beginning and end of the data
        
        data_list = all_list[start_index: end_index]
        data_list = [line.split() for line in data_list]
        data_array = np.array(data_list).astype(float)
        data_array[:,1] = 100*data_array[:,1]/np.amax(data_array[:,1])
        data_array = data_array[:,0:2]


    #   User defined words to identify start and end of the data

    else:
        if start_word != None:
            if start_word in all_list:
                start_index = all_list.index(start_word) + 1
            else: 
                print("Start word not found in the file")
        else:
            start_index = 0
            
        if end_word != None:
            if end_word in all_list:
                end_index = all_list.index(end_word)
            else:
                print("End word not found in the file")
        else: 
            end_index = len(all_list) - 1
        
        data_list = all_list[start_index: end_index]
        data_list = [line.split() for line in data_list]
        data_array = np.array(data_list).astype(float)
        data_array[:,1] = 100*data_array[:,1]/np.amax(data_array[:,1])
    
    if delta != None:
        data_array[:,0] = data_array[:,0] + float(delta)
        
    
    return data_array


def build_from_array_and_step(array, step):
    """Create a new array with the same length but with an additional axis. The first column represents the 
    physical positions of the given values. The second column is a normalization of the given array. 
    The positions are builded with evenly step spacing starting from zero.

    Parameters
    ----------

    array : ndarrya,
        Numpy 1D array with the profile values

    step : float,
        The spacing between samples

    Returns
    -------

    array, ndarray
        A new array with shape (M,2), where M is the shape of the array.

    Examples
    --------

    >>> y = np.array([2,4,6,8,10])
    >>> A = build_from_array_and_step(y, 0.5)
    [ 
    [0.0, 2] 
    [0.5, 4]         
    [1.0, 6]
    [1.5, 8]
    [2.0, 10]]

    >>> y = np.arange(6)
    >>> B = build_from_array_and_step(y, 3)
    [
    [0, 0]
    [3, 1]
    [6, 2]
    [9, 3]
    [12, 4]]

    """

    num = array.shape[0]
    start = 0
    stop = (num - 1) * step

    positions = np.linspace(start, stop, num = num, endpoint = True)
    profile = np.zeros((num, 2))
    profile[:,0] = positions
    profile[:,1] = array / np.max(array) * 100

    return profile
    

def gamma_1D(ref, eval, dose_t = 3, dist_t = 2, dose_threshold = 0, interpol = 1):
    '''
    1-dimensional gamma index calculation.
    Dose profiles have to be normalized (0-100%).

    Parameters
    ----------

    ref : ndarray,
        Reference dose profile represented by a (M, 2) numpy array.  

    eva : ndarray,
        Dose profile to be evaluated, represented by a (N, 2) numpy array.  

    dose_t : float, default = 3
            Dose tolerance [%].

    dist_t : float, default = 2
        Distance to agreement [mm].

    dose_threshold : float, default = 0
        Dose threshold [%].
        Any point in the distribution with a dose value less than the threshold 
        is going to be excluded from the analysis.
    
    interpol : float, default = 1
        Number of interpolated points to generate between each two consecutive points in "eval" data.

    Returns
    -------

    ndarray, float
        gamma distribution, gamma percent and number of evaluated points
        
    '''

    # min_position and max_position to analyze.
    min_position = np.max( (np.min(ref[:,0]), np.min([eval[:,0]])) )
    max_position = np.min( (np.max(ref[:,0]), np.max([eval[:,0]])) ) 

    num_of_points = eval.shape[0]
    interp_positions = np.linspace(ref[0,0], ref[-1,0], (interpol + 1)*(num_of_points - 1) + 1, endpoint=True)
    eval_from_interp_positions = np.interp(interp_positions, eval[:,0], eval[:,1], left = np.nan, right = np.nan) 
    add_positions = np.array((interp_positions, eval_from_interp_positions))
    eval_from_interp_positions = np.transpose(add_positions)

    #   A variable to store gamma calculations.
    gamma = np.zeros( (ref.shape[0], 2) )

    gamma[:,0] = ref[:,0]   #Add the same positions.

    for i in range(ref.shape[0]):

        if (ref[i,0] < min_position) or (ref[i,0] > max_position):  

            gamma[i, 1] = np.nan
            continue

        Gamma_appended = np.array([])  #   Gamma calculation for each point in "ref" data.
        for j in range(eval_from_interp_positions.shape[0]):

            dose_difference = ref[i,1] - eval_from_interp_positions[j,1]
            distance = ref[i,0] - eval_from_interp_positions[j,0]

            Gamma = np.sqrt(
                        (distance**2) / (dist_t**2)
                        + (dose_difference**2) / (dose_t**2))
                        
            Gamma_appended = np.append(Gamma_appended, Gamma)

        gamma[i,1] = np.min( Gamma_appended[ ~np.isnan(Gamma_appended) ] )
        if ref[i,1] < dose_threshold:
            gamma[i,1] = np.nan

    # Coordinates for gamma values <= 1.
    less_than_1_coordinate = np.where(gamma[:,1] <= 1)
    # Number of points where gamma <= 1.
    less_than_1 = np.shape(less_than_1_coordinate)[1]
    # Number evaluated points (!= nan)
    evaluated_points = np.shape(gamma)[0] - np.shape(np.where(np.isnan(gamma[:,1])))[1]
    
    gamma_percent = float(less_than_1)/evaluated_points*100

    return gamma, gamma_percent, evaluated_points


if __name__ == '__main__':
    """
    y = np.array([2,4,6,8,10])
    A = build_from_array_and_step(y, 0.5)
    print(A)

    y = np.arange(10)
    B = build_from_array_and_step(y, 3)
    print(B)

    """
    #Test files
    file_name = './test_data/test_ptw.mcc'
    #file_name = './test_data/test_varian.data'
    #file_name = './test_data/test_txt.txt'

    file_name_eval = "./test_data/X06 OPEN 10X10 PDD WAT 221214 13'13'42.mcc"
    
    data_ref = get_data(file_name, start_word =  'Field 1')
    data_eval = get_data(file_name_eval)
    g, gp = gamma_1D(data_ref, data_eval)
    print(gp)



import numpy as np
from relative_dose_1d.tools import text_to_list, get_data

lista = text_to_list("6FFF_calculated_Eclipse.txt")

array = get_data("6FFF_calculated_Eclipse.txt", start_word = "Field 1")

new_array = array[0::8,:]
#print(new_array)

np.savetxt("6FF_clinical_calc_profile.txt", new_array, fmt='%.6f', delimiter="\t")


import numpy as np
from scipy.stats import norm
from relative_dose_1d.GUI_tool import plot

# Profile positions from [-50 to 49), with 50 points.
x = np.linspace(-50, 50, 50)

# Normalized normal distribution
y = norm.pdf(x, loc = 0, scale = 15)
y = 100 * y / np.max(y)

# Define uniform random error [-4, 4)
error = 8 * np.random.random(50) - 4
y_error = y + error

p_ref = np.stack((x,y), axis = -1)
p_eval = np.stack((x,y_error), axis = -1)

plot(p_ref, p_eval)


# -*- coding: utf-8 -*-
"""
Created Apr-2023

@author: Luis Alfonso Olivares Jimenez

GUI to load text data corresponding to dose profiles and PDD. 

The data should be in M ​​rows by 2 columns, corresponding to positions and
dose values, respectively.

The script has been tested with the following examples:

    * File in w2CAD format (format used by the TPS Eclipse 16.1, from the Varian(R) company).
      In the algorithm, the start of the data is identified by the words: '$STOM' or '$STOD'
      Physical unit assumed to be in mm.

    * File in mcc format (format used by Verisoft 7.1.0.199 software, from PTW(R) company).
      In the algorithm, the beginning of the data is identified by the word: 'BEGIN_DATA'
      Physical unit assumed to be in mm.

    * File in text format
      The data must be distributed in M ​​rows by 2 columns and separated
      for a blank space.
      The script ask for a word to identify the beginning of the data in the text file, 
      a number to add to the positions, and a factor for distance dimension conversion.

After two successful loaded data, normaliztion, gamma index comparison and dose difference are automatically calculated.

"""

import sys
from PyQt6.QtWidgets import QApplication

from relative_dose_1d.GUI_tool import GUI
      
app = QApplication(sys.argv)
window = GUI()
sys.exit(app.exec())

